==> web-fw2_2_2.zip: web-fw2_2_2/j2src/sample/org/itscool/webersample/action/CustomLoginAction.java <==
package org.itscool.webersample.action;

import org.itscool.weber.action.ActionBucket;
import org.itscool.weber.action.Globals;
import org.itscool.weber.action.LoginAction;
import org.itscool.weber.user.User;
import org.itscool.webersample.bean.OfficeWorker;
import org.itscool.webersample.dao.OfficeWorkerDao;

/**
 * Webert[[NLoginActiongOCANVNXł
 */
public class CustomLoginAction extends LoginAction {
	/**
	 * OC`FbNs܂B<br>
	 * OCɐꍇ́AOC[ȔЈ擾A
	 * ActionBucketCX^XɃZbg܂<br>
	 * @param bucket ActionBucketCX^X
	 * @return ɏꍇ́AGlobals.RET_ROLE_SUCCESSԂ܂<BR>
	 * F؂ɎsꍇGlobals.RET_ROLE_FAILԂ܂
	 */
	public String doExecute(ActionBucket bucket){
		User user = (User)bucket.getForm();
        
		//F؃`FbN
        if (!isUserCheck(bucket.getRoles(), user)) {
        	//F؃G[
        	bucket.removeAttributeFromSession(Globals.REQ_PARAM_USER);
        	bucket.removeAttributeFromSession("login.worker");
            return Globals.RET_ROLE_FAIL;
        } else {
        	//ꍇ́AOC[UЈ擾
        	OfficeWorkerDao dao = new OfficeWorkerDao();
            OfficeWorker worker = dao.getWorker(OfficeWorker.COLUM_workerId, user.getName());
            if(worker != null){
            	//QXg[Ȕꍇ͎ЈZbg
            	bucket.setAttributeFromSession("login.worker", worker);
            }else{
            	//Ǘ҃[UAJ҃[U͎ЈȂ̂
            	//NULLZbg
            	bucket.removeAttributeFromSession("login.worker");
            }
            bucket.setAttributeFromSession(Globals.REQ_PARAM_USER, user);
            return Globals.RET_ROLE_SUCCESS;
        }

    }
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/sample/org/itscool/webersample/action/CustomLoginAction.java <==
package org.itscool.webersample.action;

import org.itscool.weber.action.ActionBucket;
import org.itscool.weber.action.Globals;
import org.itscool.weber.action.LoginAction;
import org.itscool.weber.user.User;
import org.itscool.webersample.bean.OfficeWorker;
import org.itscool.webersample.dao.OfficeWorkerDao;

/**
 * Webert[[NLoginActiongOCANVNXł
 */
public class CustomLoginAction extends LoginAction {
	/**
	 * OC`FbNs܂B<br>
	 * OCɐꍇ́AOC[ȔЈ擾A
	 * ActionBucketCX^XɃZbg܂<br>
	 * @param bucket ActionBucketCX^X
	 * @return ɏꍇ́AGlobals.RET_ROLE_SUCCESSԂ܂<BR>
	 * F؂ɎsꍇGlobals.RET_ROLE_FAILԂ܂
	 */
	public String doExecute(ActionBucket bucket){
		User user = (User)bucket.getForm();
        
		//F؃`FbN
        if (!isUserCheck(bucket.getRoles(), user)) {
        	//F؃G[
        	bucket.removeAttributeFromSession(Globals.REQ_PARAM_USER);
        	bucket.removeAttributeFromSession("login_worker");
            return Globals.RET_ROLE_FAIL;
        } else {
        	//ꍇ́AOC[UЈ擾
        	OfficeWorkerDao dao = new OfficeWorkerDao();
            OfficeWorker worker = dao.getWorker(OfficeWorker.COLUM_workerId, user.getName());
            if(worker != null){
            	//QXg[Ȕꍇ͎ЈZbg
            	bucket.setAttributeFromSession("login_worker", worker);
            }else{
            	//Ǘ҃[UAJ҃[U͎ЈȂ̂
            	//NULLZbg
            	bucket.removeAttributeFromSession("login_worker");
            }
            bucket.setAttributeFromSession(Globals.REQ_PARAM_USER, user);
            return Globals.RET_ROLE_SUCCESS;
        }

    }
}
